diff --git a/wlauto/workloads/appshare/__init__.py b/wlauto/workloads/appshare/__init__.py
index 80b063cf..d8bb649b 100755
--- a/wlauto/workloads/appshare/__init__.py
+++ b/wlauto/workloads/appshare/__init__.py
@@ -134,7 +134,7 @@ class AppShare(AndroidUxPerfWorkload):
super(AppShare, self).validate()
# Set package to None as it doesnt allow it to be a list,
# and we are not using it in the java side, only in wa itself.
- self.uiauto_params['package'] = None
+ self.uiauto_params['package_name'] = None
self.uiauto_params['googlephotos_package'] = self.wl_googlephotos.package
self.uiauto_params['gmail_package'] = self.wl_gmail.package
self.uiauto_params['skype_package'] = self.wl_skype.package
diff --git a/wlauto/workloads/appshare/com.arm.wlauto.uiauto.appshare.jar b/wlauto/workloads/appshare/com.arm.wlauto.uiauto.appshare.jar
deleted file mode 100644
index bdc92e2f..00000000
Binary files a/wlauto/workloads/appshare/com.arm.wlauto.uiauto.appshare.jar and /dev/null differ
diff --git a/wlauto/workloads/appshare/com.arm.wlauto.uiauto.appshare.uiautoapk b/wlauto/workloads/appshare/com.arm.wlauto.uiauto.appshare.uiautoapk
new file mode 100644
index 00000000..e11c6538
Binary files /dev/null and b/wlauto/workloads/appshare/com.arm.wlauto.uiauto.appshare.uiautoapk differ
diff --git a/wlauto/workloads/appshare/uiauto/app/build.gradle b/wlauto/workloads/appshare/uiauto/app/build.gradle
new file mode 100644
index 00000000..0ff53366
--- /dev/null
+++ b/wlauto/workloads/appshare/uiauto/app/build.gradle
@@ -0,0 +1,36 @@
+apply plugin: 'com.android.application'
+
+def packageName = "com.arm.wlauto.uiauto.appshare"
+
+
+android {
+ compileSdkVersion 25
+ buildToolsVersion "25.0.3"
+ defaultConfig {
+ applicationId "${packageName}"
+ minSdkVersion 18
+ targetSdkVersion 25
+ testInstrumentationRunner "android.support.test.runner.AndroidJUnitRunner"
+ }
+ buildTypes {
+ applicationVariants.all { variant ->
+ variant.outputs.each { output ->
+ output.outputFile = file("$project.buildDir/apk/${packageName}.apk")
+ }
+ }
+ }
+}
+
+dependencies {
+ compile fileTree(dir: 'libs', include: ['*.jar','*.java'])
+ compile 'com.android.support.test:runner:0.5'
+ compile 'com.android.support.test:rules:0.5'
+ compile 'com.android.support.test.uiautomator:uiautomator-v18:2.1.2'
+ compile(name: 'uiauto', ext:'aar')
+}
+
+repositories {
+ flatDir {
+ dirs 'libs'
+ }
+}
diff --git a/wlauto/workloads/appshare/uiauto/app/src/main/AndroidManifest.xml b/wlauto/workloads/appshare/uiauto/app/src/main/AndroidManifest.xml
new file mode 100644
index 00000000..b12652cb
--- /dev/null
+++ b/wlauto/workloads/appshare/uiauto/app/src/main/AndroidManifest.xml
@@ -0,0 +1,12 @@
+
+
+
+
+
+
+
diff --git a/wlauto/workloads/appshare/uiauto/src/com/arm/wlauto/uiauto/UiAutomation.java b/wlauto/workloads/appshare/uiauto/app/src/main/java/com/arm/wlauto/uiauto/appshare/UiAutomation.java
similarity index 84%
rename from wlauto/workloads/appshare/uiauto/src/com/arm/wlauto/uiauto/UiAutomation.java
rename to wlauto/workloads/appshare/uiauto/app/src/main/java/com/arm/wlauto/uiauto/appshare/UiAutomation.java
index f5c5f298..76b53294 100755
--- a/wlauto/workloads/appshare/uiauto/src/com/arm/wlauto/uiauto/UiAutomation.java
+++ b/wlauto/workloads/appshare/uiauto/app/src/main/java/com/arm/wlauto/uiauto/appshare/UiAutomation.java
@@ -1,20 +1,23 @@
package com.arm.wlauto.uiauto.appshare;
import android.os.Bundle;
-
-// Import the uiautomator libraries
-import com.android.uiautomator.core.UiObject;
-import com.android.uiautomator.core.UiScrollable;
-import com.android.uiautomator.core.UiSelector;
+import android.support.test.runner.AndroidJUnit4;
+import android.support.test.uiautomator.UiObject;
+import android.support.test.uiautomator.UiScrollable;
+import android.support.test.uiautomator.UiSelector;
import com.arm.wlauto.uiauto.UxPerfUiAutomation;
-import static com.arm.wlauto.uiauto.BaseUiAutomation.FindByCriteria.BY_ID;
-import static com.arm.wlauto.uiauto.BaseUiAutomation.FindByCriteria.BY_TEXT;
-import static com.arm.wlauto.uiauto.BaseUiAutomation.FindByCriteria.BY_DESC;
+import org.junit.Test;
+import org.junit.runner.RunWith;
import java.util.concurrent.TimeUnit;
+import static com.arm.wlauto.uiauto.BaseUiAutomation.FindByCriteria.BY_DESC;
+
+// Import the uiautomator libraries
+
+@RunWith(AndroidJUnit4.class)
public class UiAutomation extends UxPerfUiAutomation {
// Create UIAutomation objects
@@ -29,9 +32,11 @@ public class UiAutomation extends UxPerfUiAutomation {
public Bundle parameters;
- public void runUiAutomation() throws Exception {
+@Test
+public void runUiAutomation() throws Exception {
// Override superclass value
- this.uiAutoTimeout = TimeUnit.SECONDS.toMillis(10);
+ this.uiAutoTimeout = TimeUnit.SECONDS.toMillis(10);
+ initialize_instrumentation();
parameters = getParams();
// Setup the three uiautomator classes with the correct information
@@ -40,7 +45,11 @@ public class UiAutomation extends UxPerfUiAutomation {
Bundle dummyParams = new Bundle();
dummyParams.putString("markers_enabled", "false");
- String packageName = parameters.getString("googlephotos_package");
+ googlephotos.initialize_instrumentation();
+ skype.initialize_instrumentation();
+ gmail.initialize_instrumentation();
+
+ String packageName = parameters.getString("googlephotos_package");
googlephotos.setWorkloadParameters(dummyParams, packageName, packageName + ":id/");
packageName = parameters.getString("gmail_package");
gmail.setWorkloadParameters(dummyParams, packageName, packageName + ":id/");
@@ -63,7 +72,7 @@ public class UiAutomation extends UxPerfUiAutomation {
// On some devices the first back press only hides the keyboard, check if
// another is needed.
- UiObject googlephotosShare = new UiObject(new UiSelector().packageName(
+ UiObject googlephotosShare = mDevice.findObject(new UiSelector().packageName(
parameters.getString("googlephotos_package")));
if (!googlephotosShare.exists()){
pressBack();
@@ -88,7 +97,7 @@ public class UiAutomation extends UxPerfUiAutomation {
gmail.clearFirstRunDialogues();
UiObject composeView =
- new UiObject(new UiSelector().resourceId(gID + "compose"));
+ mDevice.findObject(new UiSelector().resourceId(gID + "compose"));
if (!composeView.waitForExists(uiAutoTimeout)) {
// After the initial share request on some devices Gmail returns back
// to the launching app, so we need to share the photo once more and
@@ -133,8 +142,8 @@ public class UiAutomation extends UxPerfUiAutomation {
new UiScrollable(new UiSelector().resourceId(googlephotos.getPackageID() + "share_expander"));
}
UiObject openApp =
- new UiObject(new UiSelector().text(appName)
- .className("android.widget.TextView"));
+ mDevice.findObject(new UiSelector().text(appName)
+ .className("android.widget.TextView"));
// On some devices the application_grid has many entries, so we have to swipe up to make
// sure all the entries are visable. This will also stop entries at the bottom being
// obscured by the bottom action bar.
@@ -143,7 +152,6 @@ public class UiAutomation extends UxPerfUiAutomation {
// In the rare case the grid is larger than the screen swipe up
applicationGrid.swipeUp(10);
}
-
logger.start();
openApp.clickAndWaitForNewWindow();
logger.stop();
diff --git a/wlauto/workloads/appshare/uiauto/build.gradle b/wlauto/workloads/appshare/uiauto/build.gradle
new file mode 100644
index 00000000..b78a0b86
--- /dev/null
+++ b/wlauto/workloads/appshare/uiauto/build.gradle
@@ -0,0 +1,23 @@
+// Top-level build file where you can add configuration options common to all sub-projects/modules.
+
+buildscript {
+ repositories {
+ jcenter()
+ }
+ dependencies {
+ classpath 'com.android.tools.build:gradle:2.3.1'
+
+ // NOTE: Do not place your application dependencies here; they belong
+ // in the individual module build.gradle files
+ }
+}
+
+allprojects {
+ repositories {
+ jcenter()
+ }
+}
+
+task clean(type: Delete) {
+ delete rootProject.buildDir
+}
diff --git a/wlauto/workloads/appshare/uiauto/build.xml b/wlauto/workloads/appshare/uiauto/build.xml
deleted file mode 100644
index bc9858a3..00000000
--- a/wlauto/workloads/appshare/uiauto/build.xml
+++ /dev/null
@@ -1,92 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/wlauto/workloads/appshare/uiauto/gradle/wrapper/gradle-wrapper.jar b/wlauto/workloads/appshare/uiauto/gradle/wrapper/gradle-wrapper.jar
new file mode 100644
index 00000000..13372aef
Binary files /dev/null and b/wlauto/workloads/appshare/uiauto/gradle/wrapper/gradle-wrapper.jar differ
diff --git a/wlauto/workloads/appshare/uiauto/gradle/wrapper/gradle-wrapper.properties b/wlauto/workloads/appshare/uiauto/gradle/wrapper/gradle-wrapper.properties
new file mode 100644
index 00000000..760fcce7
--- /dev/null
+++ b/wlauto/workloads/appshare/uiauto/gradle/wrapper/gradle-wrapper.properties
@@ -0,0 +1,6 @@
+#Wed May 03 15:42:44 BST 2017
+distributionBase=GRADLE_USER_HOME
+distributionPath=wrapper/dists
+zipStoreBase=GRADLE_USER_HOME
+zipStorePath=wrapper/dists
+distributionUrl=https\://services.gradle.org/distributions/gradle-3.3-all.zip
diff --git a/wlauto/workloads/appshare/uiauto/gradlew b/wlauto/workloads/appshare/uiauto/gradlew
new file mode 100755
index 00000000..9d82f789
--- /dev/null
+++ b/wlauto/workloads/appshare/uiauto/gradlew
@@ -0,0 +1,160 @@
+#!/usr/bin/env bash
+
+##############################################################################
+##
+## Gradle start up script for UN*X
+##
+##############################################################################
+
+# Add default JVM options here. You can also use JAVA_OPTS and GRADLE_OPTS to pass JVM options to this script.
+DEFAULT_JVM_OPTS=""
+
+APP_NAME="Gradle"
+APP_BASE_NAME=`basename "$0"`
+
+# Use the maximum available, or set MAX_FD != -1 to use that value.
+MAX_FD="maximum"
+
+warn ( ) {
+ echo "$*"
+}
+
+die ( ) {
+ echo
+ echo "$*"
+ echo
+ exit 1
+}
+
+# OS specific support (must be 'true' or 'false').
+cygwin=false
+msys=false
+darwin=false
+case "`uname`" in
+ CYGWIN* )
+ cygwin=true
+ ;;
+ Darwin* )
+ darwin=true
+ ;;
+ MINGW* )
+ msys=true
+ ;;
+esac
+
+# Attempt to set APP_HOME
+# Resolve links: $0 may be a link
+PRG="$0"
+# Need this for relative symlinks.
+while [ -h "$PRG" ] ; do
+ ls=`ls -ld "$PRG"`
+ link=`expr "$ls" : '.*-> \(.*\)$'`
+ if expr "$link" : '/.*' > /dev/null; then
+ PRG="$link"
+ else
+ PRG=`dirname "$PRG"`"/$link"
+ fi
+done
+SAVED="`pwd`"
+cd "`dirname \"$PRG\"`/" >/dev/null
+APP_HOME="`pwd -P`"
+cd "$SAVED" >/dev/null
+
+CLASSPATH=$APP_HOME/gradle/wrapper/gradle-wrapper.jar
+
+# Determine the Java command to use to start the JVM.
+if [ -n "$JAVA_HOME" ] ; then
+ if [ -x "$JAVA_HOME/jre/sh/java" ] ; then
+ # IBM's JDK on AIX uses strange locations for the executables
+ JAVACMD="$JAVA_HOME/jre/sh/java"
+ else
+ JAVACMD="$JAVA_HOME/bin/java"
+ fi
+ if [ ! -x "$JAVACMD" ] ; then
+ die "ERROR: JAVA_HOME is set to an invalid directory: $JAVA_HOME
+
+Please set the JAVA_HOME variable in your environment to match the
+location of your Java installation."
+ fi
+else
+ JAVACMD="java"
+ which java >/dev/null 2>&1 || die "ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
+
+Please set the JAVA_HOME variable in your environment to match the
+location of your Java installation."
+fi
+
+# Increase the maximum file descriptors if we can.
+if [ "$cygwin" = "false" -a "$darwin" = "false" ] ; then
+ MAX_FD_LIMIT=`ulimit -H -n`
+ if [ $? -eq 0 ] ; then
+ if [ "$MAX_FD" = "maximum" -o "$MAX_FD" = "max" ] ; then
+ MAX_FD="$MAX_FD_LIMIT"
+ fi
+ ulimit -n $MAX_FD
+ if [ $? -ne 0 ] ; then
+ warn "Could not set maximum file descriptor limit: $MAX_FD"
+ fi
+ else
+ warn "Could not query maximum file descriptor limit: $MAX_FD_LIMIT"
+ fi
+fi
+
+# For Darwin, add options to specify how the application appears in the dock
+if $darwin; then
+ GRADLE_OPTS="$GRADLE_OPTS \"-Xdock:name=$APP_NAME\" \"-Xdock:icon=$APP_HOME/media/gradle.icns\""
+fi
+
+# For Cygwin, switch paths to Windows format before running java
+if $cygwin ; then
+ APP_HOME=`cygpath --path --mixed "$APP_HOME"`
+ CLASSPATH=`cygpath --path --mixed "$CLASSPATH"`
+ JAVACMD=`cygpath --unix "$JAVACMD"`
+
+ # We build the pattern for arguments to be converted via cygpath
+ ROOTDIRSRAW=`find -L / -maxdepth 1 -mindepth 1 -type d 2>/dev/null`
+ SEP=""
+ for dir in $ROOTDIRSRAW ; do
+ ROOTDIRS="$ROOTDIRS$SEP$dir"
+ SEP="|"
+ done
+ OURCYGPATTERN="(^($ROOTDIRS))"
+ # Add a user-defined pattern to the cygpath arguments
+ if [ "$GRADLE_CYGPATTERN" != "" ] ; then
+ OURCYGPATTERN="$OURCYGPATTERN|($GRADLE_CYGPATTERN)"
+ fi
+ # Now convert the arguments - kludge to limit ourselves to /bin/sh
+ i=0
+ for arg in "$@" ; do
+ CHECK=`echo "$arg"|egrep -c "$OURCYGPATTERN" -`
+ CHECK2=`echo "$arg"|egrep -c "^-"` ### Determine if an option
+
+ if [ $CHECK -ne 0 ] && [ $CHECK2 -eq 0 ] ; then ### Added a condition
+ eval `echo args$i`=`cygpath --path --ignore --mixed "$arg"`
+ else
+ eval `echo args$i`="\"$arg\""
+ fi
+ i=$((i+1))
+ done
+ case $i in
+ (0) set -- ;;
+ (1) set -- "$args0" ;;
+ (2) set -- "$args0" "$args1" ;;
+ (3) set -- "$args0" "$args1" "$args2" ;;
+ (4) set -- "$args0" "$args1" "$args2" "$args3" ;;
+ (5) set -- "$args0" "$args1" "$args2" "$args3" "$args4" ;;
+ (6) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" ;;
+ (7) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" "$args6" ;;
+ (8) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" "$args6" "$args7" ;;
+ (9) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" "$args6" "$args7" "$args8" ;;
+ esac
+fi
+
+# Split up the JVM_OPTS And GRADLE_OPTS values into an array, following the shell quoting and substitution rules
+function splitJvmOpts() {
+ JVM_OPTS=("$@")
+}
+eval splitJvmOpts $DEFAULT_JVM_OPTS $JAVA_OPTS $GRADLE_OPTS
+JVM_OPTS[${#JVM_OPTS[*]}]="-Dorg.gradle.appname=$APP_BASE_NAME"
+
+exec "$JAVACMD" "${JVM_OPTS[@]}" -classpath "$CLASSPATH" org.gradle.wrapper.GradleWrapperMain "$@"
diff --git a/wlauto/workloads/appshare/uiauto/gradlew.bat b/wlauto/workloads/appshare/uiauto/gradlew.bat
new file mode 100644
index 00000000..aec99730
--- /dev/null
+++ b/wlauto/workloads/appshare/uiauto/gradlew.bat
@@ -0,0 +1,90 @@
+@if "%DEBUG%" == "" @echo off
+@rem ##########################################################################
+@rem
+@rem Gradle startup script for Windows
+@rem
+@rem ##########################################################################
+
+@rem Set local scope for the variables with windows NT shell
+if "%OS%"=="Windows_NT" setlocal
+
+@rem Add default JVM options here. You can also use JAVA_OPTS and GRADLE_OPTS to pass JVM options to this script.
+set DEFAULT_JVM_OPTS=
+
+set DIRNAME=%~dp0
+if "%DIRNAME%" == "" set DIRNAME=.
+set APP_BASE_NAME=%~n0
+set APP_HOME=%DIRNAME%
+
+@rem Find java.exe
+if defined JAVA_HOME goto findJavaFromJavaHome
+
+set JAVA_EXE=java.exe
+%JAVA_EXE% -version >NUL 2>&1
+if "%ERRORLEVEL%" == "0" goto init
+
+echo.
+echo ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
+echo.
+echo Please set the JAVA_HOME variable in your environment to match the
+echo location of your Java installation.
+
+goto fail
+
+:findJavaFromJavaHome
+set JAVA_HOME=%JAVA_HOME:"=%
+set JAVA_EXE=%JAVA_HOME%/bin/java.exe
+
+if exist "%JAVA_EXE%" goto init
+
+echo.
+echo ERROR: JAVA_HOME is set to an invalid directory: %JAVA_HOME%
+echo.
+echo Please set the JAVA_HOME variable in your environment to match the
+echo location of your Java installation.
+
+goto fail
+
+:init
+@rem Get command-line arguments, handling Windowz variants
+
+if not "%OS%" == "Windows_NT" goto win9xME_args
+if "%@eval[2+2]" == "4" goto 4NT_args
+
+:win9xME_args
+@rem Slurp the command line arguments.
+set CMD_LINE_ARGS=
+set _SKIP=2
+
+:win9xME_args_slurp
+if "x%~1" == "x" goto execute
+
+set CMD_LINE_ARGS=%*
+goto execute
+
+:4NT_args
+@rem Get arguments from the 4NT Shell from JP Software
+set CMD_LINE_ARGS=%$
+
+:execute
+@rem Setup the command line
+
+set CLASSPATH=%APP_HOME%\gradle\wrapper\gradle-wrapper.jar
+
+@rem Execute Gradle
+"%JAVA_EXE%" %DEFAULT_JVM_OPTS% %JAVA_OPTS% %GRADLE_OPTS% "-Dorg.gradle.appname=%APP_BASE_NAME%" -classpath "%CLASSPATH%" org.gradle.wrapper.GradleWrapperMain %CMD_LINE_ARGS%
+
+:end
+@rem End local scope for the variables with windows NT shell
+if "%ERRORLEVEL%"=="0" goto mainEnd
+
+:fail
+rem Set variable GRADLE_EXIT_CONSOLE if you need the _script_ return code instead of
+rem the _cmd.exe /c_ return code!
+if not "" == "%GRADLE_EXIT_CONSOLE%" exit 1
+exit /b 1
+
+:mainEnd
+if "%OS%"=="Windows_NT" endlocal
+
+:omega
diff --git a/wlauto/workloads/appshare/uiauto/project.properties b/wlauto/workloads/appshare/uiauto/project.properties
deleted file mode 100644
index ce39f2d0..00000000
--- a/wlauto/workloads/appshare/uiauto/project.properties
+++ /dev/null
@@ -1,14 +0,0 @@
-# This file is automatically generated by Android Tools.
-# Do not modify this file -- YOUR CHANGES WILL BE ERASED!
-#
-# This file must be checked in Version Control Systems.
-#
-# To customize properties used by the Ant build system edit
-# "ant.properties", and override values to adapt the script to your
-# project structure.
-#
-# To enable ProGuard to shrink and obfuscate your code, uncomment this (available properties: sdk.dir, user.home):
-#proguard.config=${sdk.dir}/tools/proguard/proguard-android.txt:proguard-project.txt
-
-# Project target.
-target=android-18
diff --git a/wlauto/workloads/appshare/uiauto/settings.gradle b/wlauto/workloads/appshare/uiauto/settings.gradle
new file mode 100644
index 00000000..42244f86
--- /dev/null
+++ b/wlauto/workloads/appshare/uiauto/settings.gradle
@@ -0,0 +1 @@
+include ':app', ':gmail'
diff --git a/wlauto/workloads/appshare/uiauto/build.sh b/wlauto/workloads/appshare/uiauto/build.sh
index aefd6ede..6a57dc18 100755
--- a/wlauto/workloads/appshare/uiauto/build.sh
+++ b/wlauto/workloads/appshare/uiauto/build.sh
@@ -8,42 +8,46 @@ fi
script_dir=`dirname $script_path`
cd $script_dir
-# Ensure build.xml exists before starting
-if [[ ! -f build.xml ]]; then
- echo 'Ant build.xml file not found! Check that you are in the right directory.'
+# Ensure gradelw exists before starting
+if [[ ! -f gradlew ]]; then
+ echo 'gradlew file not found! Check that you are in the right directory.'
exit 9
fi
-# Copy base classes from wlauto dist
-class_dir=bin/classes/com/arm/wlauto/uiauto
-base_classes=`python -c "import os, wlauto; print os.path.join(os.path.dirname(wlauto.__file__), 'common', 'android', '*.class')"`
-mkdir -p $class_dir
-cp $base_classes $class_dir
+# Copy base class library from wlauto dist
+libs_dir=app/libs
+base_classes=`python -c "import os, wlauto; print os.path.join(os.path.dirname(wlauto.__file__), 'common', 'android', '*.aar')"`
+mkdir -p $libs_dir
+cp $base_classes $libs_dir
# Add appshare workload dependencies
apps=("googlephotos" "gmail" "skype")
+# Copy the dependant workload classes source code.
for app in "${apps[@]}"; do
module_path="wlauto.workloads.${app}"
- app_path="'uiauto/bin/classes/com/arm/wlauto/uiauto/${app}'"
- app_class_dir=`python -c "import os, ${module_path}; print os.path.join(os.path.dirname(${module_path}.__file__), ${app_path})"`
- cp -r $app_class_dir $class_dir
+ app_path="'uiauto/app/src/main/java/com/arm/wlauto/uiauto/${app}'"
+ app_libs_dir=`python -c "import os, ${module_path}; print os.path.join(os.path.dirname(${module_path}.__file__), ${app_path})"`
+ cp -r $app_libs_dir "app/src/main/java/com/arm/wlauto/uiauto"
done
+
+
# Build and return appropriate exit code if failed
-ant build
+# gradle build
+./gradlew clean :app:assembleDebug
exit_code=$?
if [[ $exit_code -ne 0 ]]; then
- echo "ERROR: 'ant build' exited with code $exit_code"
+ echo "ERROR: 'gradle build' exited with code $exit_code"
exit $exit_code
fi
-# If successful move JAR file to workload folder (overwrite previous)
-package=com.arm.wlauto.uiauto.appshare.jar
+# If successful move APK file to workload folder (overwrite previous)
+package=com.arm.wlauto.uiauto.appshare
rm -f ../$package
-if [[ -f bin/$package ]]; then
- cp bin/$package ..
+if [[ -f app/build/apk/$package.apk ]]; then
+ cp app/build/apk/$package.apk ../$package.uiautoapk
else
- echo 'ERROR: UiAutomator JAR could not be found!'
+ echo 'ERROR: UiAutomator apk could not be found!'
exit 9
fi